==> huaweicloudsdkcloudtest-3.1.110-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/dns_mapping_node.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DnsMappingNode:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain_name': 'str',
        'ips': 'list[str]'
    }

    attribute_map = {
        'domain_name': 'domain_name',
        'ips': 'ips'
    }

    def __init__(self, domain_name=None, ips=None):
        """DnsMappingNode

        The model defined in huaweicloud sdk

        :param domain_name: 域名信息
        :type domain_name: str
        :param ips: 域名对应的IP
        :type ips: list[str]
        """
        
        

        self._domain_name = None
        self._ips = None
        self.discriminator = None

        if domain_name is not None:
            self.domain_name = domain_name
        if ips is not None:
            self.ips = ips

    @property
    def domain_name(self):
        """Gets the domain_name of this DnsMappingNode.

        域名信息

        :return: The domain_name of this DnsMappingNode.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this DnsMappingNode.

        域名信息

        :param domain_name: The domain_name of this DnsMappingNode.
        :type domain_name: str
        """
        self._domain_name = domain_name

    @property
    def ips(self):
        """Gets the ips of this DnsMappingNode.

        域名对应的IP

        :return: The ips of this DnsMappingNode.
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this DnsMappingNode.

        域名对应的IP

        :param ips: The ips of this DnsMappingNode.
        :type ips: list[str]
        """
        self._ips = ips

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DnsMappingNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/dns_mapping_node.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DnsMappingNode:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain_name': 'str',
        'ips': 'list[str]'
    }

    attribute_map = {
        'domain_name': 'domain_name',
        'ips': 'ips'
    }

    def __init__(self, domain_name=None, ips=None):
        r"""DnsMappingNode

        The model defined in huaweicloud sdk

        :param domain_name: 域名信息
        :type domain_name: str
        :param ips: 域名对应的IP
        :type ips: list[str]
        """
        
        

        self._domain_name = None
        self._ips = None
        self.discriminator = None

        if domain_name is not None:
            self.domain_name = domain_name
        if ips is not None:
            self.ips = ips

    @property
    def domain_name(self):
        r"""Gets the domain_name of this DnsMappingNode.

        域名信息

        :return: The domain_name of this DnsMappingNode.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        r"""Sets the domain_name of this DnsMappingNode.

        域名信息

        :param domain_name: The domain_name of this DnsMappingNode.
        :type domain_name: str
        """
        self._domain_name = domain_name

    @property
    def ips(self):
        r"""Gets the ips of this DnsMappingNode.

        域名对应的IP

        :return: The ips of this DnsMappingNode.
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        r"""Sets the ips of this DnsMappingNode.

        域名对应的IP

        :param ips: The ips of this DnsMappingNode.
        :type ips: list[str]
        """
        self._ips = ips

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DnsMappingNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
